package intro.carrier2;

import java.util.Properties;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceListener;
import org.osgi.framework.ServiceEvent;

import intro.carrier.service.FlightService;

/**
 * This class implements a simple bundle that uses the bundle
 * context to register domestic flight availability service
 * with the OSGi framework. The flight service interface is
 * defined in a separate class file and is implemented by an
 * inner class.This class is identical to the class in
 * carrier, except that the flight service offers domestic seating
**/
public class Activator implements BundleActivator
{
    /**
     * Implements BundleActivator.start(). Registers an
     * instance of a flight service using the bundle context;
     * attaches properties to the service that can be queried
     * when performing a service look-up.
     * @param context the framework context for the bundle.
    **/
    public void start(BundleContext context)
    {
        Properties props = new Properties();
        props.put("Seating", "Domestic");
        context.registerService(
            FlightService.class.getName(), new FlightImpl(), props);
    }

    /**
     * Implements BundleActivator.stop(). Does nothing since
     * the framework will automatically unregister any registered services.
     * @param context the framework context for the bundle.
    **/
    public void stop(BundleContext context)
    {
        // NOTE: The service is automatically unregistered.
    }

    /**
     * A private inner class that implements a flight service;
     * see FlightService for details of the service.
    **/
    private static class FlightImpl implements FlightService
    {
        // The set of cities contained in the flight service
        String[] c_flight =
            { "san francisco", "new york", "los angeles", "miami", "seattle" };

        /**
         * Implements FlightService.checkAvailability(). Determines
         * if the passed in city is available 
         * @param flight the flight to be checked.
         * @return true if the flight seating is available,
         *         false otherwise.
        **/
        public boolean checkAvailability(String flight)
        {
            flight = flight.toLowerCase();

            for (int i = 0; i < c_flight.length; i++)
            {
                if (c_flight[i].startsWith(flight))
                {
                    return true;
                }
            }
            return false;
        }
    }
}
